serialize

Function serialize 

pub fn serialize<S>(
    value: &Option<OrderSide>,
    serializer: S,
) -> Result<S::Ok, S::Error>
where S: Serializer,
Serializes an optional order side using the legacy no-side token.

Errors

Returns an error if the serializer cannot encode the value.