pub fn serialize<S>(
value: &Option<OrderSide>,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,Expand description
Serializes an optional order side using the legacy no-side token.
Errors
Returns an error if the serializer cannot encode the value.